@@ -24,7 +24,7 @@ quickregister(
             "enable",
         ]
     ),
-    addview=AddView._with(fields=["model", "type", "action"]),
+    addview=AddView._with(fields=["description", "model", "type", "action"]),
 )
 quickregister(
     urlpatterns,
@@ -43,7 +43,14 @@ quickregister(
         ]
     ),
     addview=AddView._with(
-        fields=["model", "action", "offset_type", "offset_amount", "field"]
+        fields=[
+            "description",
+            "model",
+            "action",
+            "offset_type",
+            "offset_amount",
+            "field",
+        ]
     ),
 )
 quickregister(urlpatterns, SendEmail)
